import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:get_it/get_it.dart';
import 'package:starting_template/core/enums/dev_mode.dart';
import 'package:starting_template/core/flavors/flavor.dart';
import 'package:starting_template/core/utils/firebase_emulator.dart';

final getIt = GetIt.I;

/// Service and Data Source locator
abstract class GetItInitializer {
  static FutureOr<void> _initCommon() async {
    // TODO(wyatt): Initialize common sources/services
  }

  static FutureOr<void> _initMock() async {
    // TODO(wyatt): Initialize mocked sources/services.
  }

  static FutureOr<void> _initLocal() async {
    // TODO(wyatt): Initialize local sources/services.
    final emulator = FirebaseEmulator.fromEnv();
    debugPrint('Firebase Emulator: $emulator');
  }

  static FutureOr<void> _initReal() async {
    // TODO(wyatt): Initialize real sources/services
  }

  static FutureOr<void> init() async {
    // Initialize common sources/services
    await _initCommon();

    // Initialize sources/services based on flavor
    switch (Flavor.instance.devMode) {
      case DevMode.mock:
        await _initMock();
        break;
      case DevMode.local:
        await _initLocal();
        break;
      case DevMode.real:
        await _initReal();
        break;
      case null:
        throw Exception('DevMode not initialized!');
    }

    await getIt.allReady();
  }
}
