import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:starting_template/core/enums/build_mode.dart';
import 'package:starting_template/core/enums/dev_mode.dart';

class Flavor {
  Flavor._({
    this.flavorName,
    this.bannerColor,
  }) {
    // Determine build mode
    buildMode = kReleaseMode
        ? BuildMode.release
        : kProfileMode
            ? BuildMode.profile
            : BuildMode.debug;

    // Retrieve dev mode, fallback to mock
    devMode = DevMode.fromString(
      const String.fromEnvironment('DEV_MODE', defaultValue: 'mock'),
    );

    _instance = this;
  }

  static Flavor? _instance;

  final String? flavorName;
  final Color? bannerColor;

  late final DevMode? devMode;
  late final BuildMode? buildMode;

  /// Returns [Flavor] instance.
  static Flavor get instance {
    if (_instance == null) {
      throw Exception('Flavor not initialized!');
    }

    return _instance!;
  }

  String get name => flavorName ?? 'Unknown';
  Color get color => bannerColor ?? Colors.grey;

  static bool shouldShowBanner() => instance.buildMode != BuildMode.release;

  @override
  String toString() =>
      'Flavor: $flavorName, DevMode: $devMode, BuildMode: $buildMode';
}

class DevelopmentFlavor extends Flavor {
  DevelopmentFlavor()
      : super._(flavorName: 'Development', bannerColor: Colors.red);
}

class StagingFlavor extends Flavor {
  StagingFlavor() : super._(flavorName: 'Staging', bannerColor: Colors.orange);
}

class ProductionFlavor extends Flavor {
  ProductionFlavor()
      : super._(flavorName: 'Production', bannerColor: Colors.green);
}
