// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:{{#snakeCase}}{{project_name}}{{/snakeCase}}/core/constants/emulator.dart';

class FirebaseEmulator {
  const FirebaseEmulator._({
    required this.cloudFunctionPort,
    required this.firestorePort,
    required this.authPort,
    required this.storagePort,
    required this.host,
  });

  factory FirebaseEmulator.fromEnv() => const FirebaseEmulator._(
        cloudFunctionPort: int.fromEnvironment(
          Emulator.firebaseCloudFunctionEnvKey,
          defaultValue: Emulator.defaultFirebaseCloudFunctionPort,
        ),
        firestorePort: int.fromEnvironment(
          Emulator.firebaseFirestoreEnvKey,
          defaultValue: Emulator.defaultFirebaseFirestorePort,
        ),
        authPort: int.fromEnvironment(
          Emulator.firebaseAuthEnvKey,
          defaultValue: Emulator.defaultFirebaseAuthPort,
        ),
        storagePort: int.fromEnvironment(
          Emulator.firebaseStorageEnvKey,
          defaultValue: Emulator.defaultFirebaseStoragePort,
        ),
        host: String.fromEnvironment(
          Emulator.hostEnvKey,
          defaultValue: Emulator.defaultHost,
        ),
      );

  final int cloudFunctionPort;
  final int firestorePort;
  final int authPort;
  final int storagePort;
  final String host;

  @override
  String toString() => 'FirebaseEmulator(cloudFunctionPort: '
      '$cloudFunctionPort, firestorePort: $firestorePort, authPort: $authPort, '
      'storagePort: $storagePort, host: $host)';
}
